==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sk_SK.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Sťahovanie tokenov požiadavky zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Sťahovanie prístupových tokenov zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Please provide a valid app key and secret." : "Zadajte prosím platný aplikačný kľúč a heslo (secret).",
    "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
    "External storage" : "Externé úložisko",
    "Storage with id \"%i\" not found" : "Úložisko s ID \"%i\" sa nenašlo",
    "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
    "Invalid mount point" : "Chybný prípojný bod",
    "Objectstore forbidden" : "Objectstore je zakáazaný",
    "Invalid storage backend \"%s\"" : "Neplatný backend úložiska \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie je povolené použiť backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
    "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
    "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
    "Personal" : "Osobné",
    "System" : "Systém",
    "Grant access" : "Povoliť prístup",
    "Access granted" : "Prístup povolený",
    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
    "Generate keys" : "Vytvoriť kľúče",
    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
    "Enable encryption" : "Povoliť šifrovanie",
    "Enable previews" : "Povoliť náhľady",
    "Check for changes" : "Zisťovať zmeny",
    "Never" : "Nikdy",
    "Once every direct access" : "S každým priamym prístupom",
    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
    "(group)" : "(skupina)",
    "Saved" : "Uložené",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Save" : "Uložiť",
    "Access key" : "Prístupový kľúč",
    "Secret key" : "Tajný kľúč",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "OAuth1" : "OAuth1",
    "App key" : "Kľúč aplikácie",
    "App secret" : "Heslo aplikácie",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Heslo klienta",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Meno nájomcu",
    "Identity endpoint URL" : "Endpoint URL identita",
    "Rackspace" : "Rackspace",
    "API key" : "API kľúč",
    "Username and password" : "Meno a heslo",
    "RSA public key" : "RSA verejný kľúč",
    "Public key" : "Verejný kľúč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Sektor",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Región",
    "Enable SSL" : "Povoliť SSL",
    "Enable Path Style" : "Povoliť štýl cesty",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdialený podpriečinok",
    "Secure https://" : "Zabezpečené https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Hostiteľ",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokálny",
    "Location" : "Umiestnenie",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Zdieľať",
    "Domain" : "Doména",
    "SMB / CIFS using OC login" : "SMB / CIFS s použitím OC prihlásenia",
    "Username as share" : "Používateľské meno ako zdieľaný priečinok",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Názov služby",
    "Request timeout (seconds)" : "Timeout požiadavky (s)",
    "<b>Note:</b> " : "<b>Poznámka:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> cURL podpora v PHP nie je zapnutá alebo nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> FTP podpora v PHP nie je zapnutá alebo nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> \"%s\" nie je nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "No external storage configured" : "Žiadne externé úložisko nie je nakonfigurované",
    "You can add external storages in the personal settings" : "Externé úložisko je možné pridať v osobných nastaveniach",
    "Name" : "Názov",
    "Storage type" : "Typ úložiska",
    "Scope" : "Rozsah",
    "External Storage" : "Externé úložisko",
    "Folder name" : "Názov priečinka",
    "Authentication" : "Autentifikácia",
    "Configuration" : "Nastavenia",
    "Available for" : "K dispozícii pre",
    "Add storage" : "Pridať úložisko",
    "Advanced settings" : "Rozšírené nastavenia",
    "Delete" : "Zmazať",
    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sk_SK.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Sťahovanie tokenov požiadavky zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Sťahovanie prístupových tokenov zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Please provide a valid app key and secret." : "Zadajte prosím platný aplikačný kľúč a heslo (secret).",
    "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
    "External storage" : "Externé úložisko",
    "Storage with id \"%i\" not found" : "Úložisko s ID \"%i\" sa nenašlo",
    "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
    "Invalid mount point" : "Chybný prípojný bod",
    "Objectstore forbidden" : "Objectstore je zakáazaný",
    "Invalid storage backend \"%s\"" : "Neplatný backend úložiska \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie je povolené použiť backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
    "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
    "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
    "Personal" : "Osobné",
    "System" : "Systém",
    "Grant access" : "Povoliť prístup",
    "Access granted" : "Prístup povolený",
    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
    "Generate keys" : "Vytvoriť kľúče",
    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
    "Enable encryption" : "Povoliť šifrovanie",
    "Enable previews" : "Povoliť náhľady",
    "Check for changes" : "Zisťovať zmeny",
    "Never" : "Nikdy",
    "Once every direct access" : "S každým priamym prístupom",
    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
    "(group)" : "(skupina)",
    "Saved" : "Uložené",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Save" : "Uložiť",
    "Access key" : "Prístupový kľúč",
    "Secret key" : "Tajný kľúč",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "OAuth1" : "OAuth1",
    "App key" : "Kľúč aplikácie",
    "App secret" : "Heslo aplikácie",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Heslo klienta",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Meno nájomcu",
    "Identity endpoint URL" : "Endpoint URL identita",
    "Rackspace" : "Rackspace",
    "API key" : "API kľúč",
    "Username and password" : "Meno a heslo",
    "RSA public key" : "RSA verejný kľúč",
    "Public key" : "Verejný kľúč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Sektor",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Región",
    "Enable SSL" : "Povoliť SSL",
    "Enable Path Style" : "Povoliť štýl cesty",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdialený podpriečinok",
    "Secure https://" : "Zabezpečené https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Hostiteľ",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokálny",
    "Location" : "Umiestnenie",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Zdieľať",
    "Domain" : "Doména",
    "SMB / CIFS using OC login" : "SMB / CIFS s použitím OC prihlásenia",
    "Username as share" : "Používateľské meno ako zdieľaný priečinok",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Názov služby",
    "Request timeout (seconds)" : "Timeout požiadavky (s)",
    "<b>Note:</b> " : "<b>Poznámka:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> cURL podpora v PHP nie je zapnutá alebo nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> FTP podpora v PHP nie je zapnutá alebo nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> \"%s\" nie je nainštalovaná. Pripojenie %s nie je možné. Požiadajte správcu systému, aby ju nainštaloval.",
    "No external storage configured" : "Žiadne externé úložisko nie je nakonfigurované",
    "You can add external storages in the personal settings" : "Externé úložisko je možné pridať v osobných nastaveniach",
    "Name" : "Názov",
    "Storage type" : "Typ úložiska",
    "Scope" : "Rozsah",
    "External Storage" : "Externé úložisko",
    "Folder name" : "Názov priečinka",
    "Authentication" : "Autentifikácia",
    "Configuration" : "Nastavenia",
    "Available for" : "K dispozícii pre",
    "Add storage" : "Pridať úložisko",
    "Advanced settings" : "Rozšírené nastavenia",
    "Delete" : "Zmazať",
    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
